embassy-stm32

Crates

git

Versions

stm32wl54jc-cm0p

Flavors

IpccRxChannel

Struct IpccRxChannel 

pub struct IpccRxChannel<'a> { /* private fields */ }
IPCC RX Channel

Implementations

Source

impl<'a> IpccRxChannel<'a>

pub async fn receive<R>( &mut self, f: impl FnMut() -> Option<R>, close: bool, ) -> R

Receive data from an IPCC channel. The closure is called to read the data when appropriate.

close determines whether the channel will be open for receiving more data, or not after data is read.